{% extends 'dcim/device/base.html' %}
{% load helpers %}

{% block content %}
{% if loading %}
<div id="ise-content"
     hx-get="{% url 'plugins:netbox_cisco_ise:device_content' pk=object.pk %}"
     hx-trigger="load"
     hx-swap="innerHTML">
    <div class="d-flex justify-content-center align-items-center py-5">
        <div class="text-center">
            <div class="spinner-border text-primary mb-3" role="status" style="width: 3rem; height: 3rem;">
                <span class="visually-hidden">Loading...</span>
            </div>
            <p class="text-muted mb-0">Loading Cisco ISE data...</p>
        </div>
    </div>
</div>
{% elif error %}
<div class="alert alert-warning">
    <i class="mdi mdi-alert"></i> {{ error }}
</div>
{% endif %}
{% endblock %}
